@@ -1,7 +1,10 @@
 mod auth;
 mod config;
 mod connection;
+
 mod tls;
+#[cfg(any(feature = "rustls", feature = "native-tls"))]
+mod tls_stream;
 
 pub use auth::*;
 pub use config::*;
