@@ -48,7 +48,10 @@ impl Default for Config {
             database: None,
             instance_name: None,
             application_name: None,
+            #[cfg(any(feature = "rustls", feature = "native-tls"))]
             encryption: EncryptionLevel::Required,
+            #[cfg(not(any(feature = "rustls", feature = "native-tls")))]
+            encryption: EncryptionLevel::NotSupported,
             trust: TrustConfig::Default,
             auth: AuthMethod::None,
         }
@@ -323,6 +326,7 @@ pub(crate) trait ConfigString {
             .map(|ca| ca.to_string())
     }
 
+    #[cfg(any(feature = "rustls", feature = "native-tls"))]
     fn encrypt(&self) -> crate::Result<EncryptionLevel> {
         self.dict()
             .get("encrypt")
@@ -335,6 +339,11 @@ pub(crate) trait ConfigString {
             .unwrap_or(Ok(EncryptionLevel::Off))
     }
 
+    #[cfg(not(any(feature = "rustls", feature = "native-tls")))]
+    fn encrypt(&self) -> crate::Result<EncryptionLevel> {
+        Ok(EncryptionLevel::NotSupported)
+    }
+
     fn parse_bool<T: AsRef<str>>(v: T) -> crate::Result<bool> {
         match v.as_ref().trim().to_lowercase().as_str() {
             "true" | "yes" => Ok(true),
