@@ -1,10 +1,7 @@
-use crate::error::IoErrorKind;
+#[cfg(any(feature = "rustls", feature = "native-tls"))]
+use crate::client::{tls::TlsPreloginWrapper, tls_stream::create_tls_stream};
 use crate::{
-    client::{
-        tls::{MaybeTlsStream, TlsPreloginWrapper},
-        AuthMethod, Config, TrustConfig,
-    },
-    error::Error,
+    client::{tls::MaybeTlsStream, AuthMethod, Config},
     tds::{
         codec::{
             self, Encode, LoginMessage, Packet, PacketCodec, PacketHeader, PacketStatus,
@@ -15,8 +12,6 @@ use crate::{
     },
     EncryptionLevel, SqlReadBytes,
 };
-#[cfg(not(any(target_os = "macos", target_os = "ios")))]
-use async_native_tls::{Certificate, TlsConnector};
 use asynchronous_codec::Framed;
 use bytes::BytesMut;
 #[cfg(any(windows, feature = "integrated-auth-gssapi"))]
@@ -29,12 +24,10 @@ use libgssapi::{
     name::Name,
     oid::{OidSet, GSS_MECH_KRB5, GSS_NT_KRB5_PRINCIPAL},
 };
-#[cfg(any(target_os = "macos", target_os = "ios"))]
-use opentls::{async_io::TlsConnector, Certificate};
 use pretty_hex::*;
 #[cfg(all(unix, feature = "integrated-auth-gssapi"))]
 use std::ops::Deref;
-use std::{cmp, fmt::Debug, fs, io, pin::Pin, task};
+use std::{cmp, fmt::Debug, io, pin::Pin, task};
 use task::Poll;
 use tracing::{event, Level};
 #[cfg(all(windows, feature = "winauth"))]
@@ -119,6 +112,7 @@ impl<S: AsyncRead + AsyncWrite + Unpin + Send> Connection<S> {
         TokenStream::new(self).flush_sspi().await
     }
 
+    #[cfg(any(feature = "rustls", feature = "native-tls"))]
     fn post_login_encryption(mut self, encryption: EncryptionLevel) -> Self {
         if let EncryptionLevel::Off = encryption {
             event!(
@@ -134,6 +128,11 @@ impl<S: AsyncRead + AsyncWrite + Unpin + Send> Connection<S> {
         self
     }
 
+    #[cfg(not(any(feature = "rustls", feature = "native-tls")))]
+    fn post_login_encryption(self, _: EncryptionLevel) -> Self {
+        self
+    }
+
     /// Send an item to the wire. Header should define the item type and item should implement
     /// [`Encode`], defining the byte structure for the wire.
     ///
@@ -371,6 +370,7 @@ impl<S: AsyncRead + AsyncWrite + Unpin + Send> Connection<S> {
     }
 
     /// Implements the TLS handshake with the SQL Server.
+    #[cfg(any(feature = "rustls", feature = "native-tls"))]
     async fn tls_handshake(
         self,
         config: &Config,
@@ -379,58 +379,12 @@ impl<S: AsyncRead + AsyncWrite + Unpin + Send> Connection<S> {
         if encryption != EncryptionLevel::NotSupported {
             event!(Level::INFO, "Performing a TLS handshake");
 
-            let mut builder = TlsConnector::new();
-
-            match &config.trust {
-                TrustConfig::CaCertificateLocation(path) => {
-                    if let Ok(buf) = fs::read(path) {
-                        let cert = match path.extension() {
-                            Some(ext)
-                                if ext.to_ascii_lowercase() == "pem"
-                                    || ext.to_ascii_lowercase() == "crt" =>
-                            {
-                                Some(Certificate::from_pem(&buf)?)
-                            }
-                            Some(ext) if ext.to_ascii_lowercase() == "der" => {
-                                Some(Certificate::from_der(&buf)?)
-                            }
-                            Some(_) | None => return Err(Error::Io {
-                                kind: IoErrorKind::InvalidInput,
-                                message: "Provided CA certificate with unsupported file-extension! Supported types are pem, crt and der.".to_string()}),
-                        };
-                        if let Some(c) = cert {
-                            builder = builder.add_root_certificate(c);
-                        }
-                    } else {
-                        return Err(Error::Io {
-                            kind: IoErrorKind::InvalidData,
-                            message: "Could not read provided CA certificate!".to_string(),
-                        });
-                    }
-                }
-                TrustConfig::TrustAll => {
-                    event!(
-                        Level::WARN,
-                        "Trusting the server certificate without validation."
-                    );
-
-                    builder = builder.danger_accept_invalid_certs(true);
-                    builder = builder.danger_accept_invalid_hostnames(true);
-                    builder = builder.use_sni(false);
-                }
-                TrustConfig::Default => {
-                    event!(Level::INFO, "Using default trust configuration.");
-                }
-            }
-
             let Self {
                 transport, context, ..
             } = self;
             let mut stream = match transport.release().0 {
                 MaybeTlsStream::Raw(tcp) => {
-                    builder
-                        .connect(config.get_host(), TlsPreloginWrapper::new(tcp))
-                        .await?
+                    create_tls_stream(config, TlsPreloginWrapper::new(tcp)).await?
                 }
                 _ => unreachable!(),
             };
@@ -455,6 +409,17 @@ impl<S: AsyncRead + AsyncWrite + Unpin + Send> Connection<S> {
             Ok(self)
         }
     }
+
+    /// Implements the TLS handshake with the SQL Server.
+    #[cfg(not(any(feature = "rustls", feature = "native-tls")))]
+    async fn tls_handshake(self, _: &Config, _: EncryptionLevel) -> crate::Result<Self> {
+        event!(
+            Level::WARN,
+            "TLS encryption is not enabled. All traffic including the login credentials are not encrypted."
+        );
+
+        Ok(self)
+    }
 }
 
 impl<S: AsyncRead + AsyncWrite + Unpin + Send> Stream for Connection<S> {
